===============================
ometria
===============================

.. image:: https://badge.fury.io/py/ometria.png
    :target: http://badge.fury.io/py/ometria
    
.. image:: https://travis-ci.org/nwjlyons/ometria.png?branch=master
        :target: https://travis-ci.org/nwjlyons/ometria

.. image:: https://pypip.in/d/ometria/badge.png
        :target: https://crate.io/packages/ometria?version=latest


Python wrapper for the Ometria API

* Free software: BSD license
* Documentation: http://ometria.rtfd.org.

Features
--------

* TODO